package com.ygtx.gxt.mapper;

import java.util.List;
import com.ygtx.gxt.domain.GxtOrderScoreDetail;

/**
 * 工单个人分数明细Mapper接口
 * 
 * @author ouyj
 * @date 2026-01-21
 */
public interface GxtOrderScoreDetailMapper 
{
    /**
     * 查询工单个人分数明细
     * 
     * @param id 工单个人分数明细主键
     * @return 工单个人分数明细
     */
    public GxtOrderScoreDetail selectGxtOrderScoreDetailById(Long id);

    /**
     * 查询工单个人分数明细列表
     * 
     * @param gxtOrderScoreDetail 工单个人分数明细
     * @return 工单个人分数明细集合
     */
    public List<GxtOrderScoreDetail> selectGxtOrderScoreDetailList(GxtOrderScoreDetail gxtOrderScoreDetail);

    /**
     * 新增工单个人分数明细
     * 
     * @param gxtOrderScoreDetail 工单个人分数明细
     * @return 结果
     */
    public int insertGxtOrderScoreDetail(GxtOrderScoreDetail gxtOrderScoreDetail);

    /**
     * 修改工单个人分数明细
     * 
     * @param gxtOrderScoreDetail 工单个人分数明细
     * @return 结果
     */
    public int updateGxtOrderScoreDetail(GxtOrderScoreDetail gxtOrderScoreDetail);

    /**
     * 删除工单个人分数明细
     * 
     * @param id 工单个人分数明细主键
     * @return 结果
     */
    public int deleteGxtOrderScoreDetailById(Long id);

    /**
     * 批量删除工单个人分数明细
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGxtOrderScoreDetailByIds(Long[] ids);
}
